@@ -1,7 +1,10 @@
 from .chisquare import ChiSquareDrift
 from .classifier import ClassifierDrift
 from .ks import KSDrift
+from .lsdd import LSDDDrift
+from .lsdd_online import LSDDDriftOnline
 from .mmd import MMDDrift
+from .mmd_online import MMDDriftOnline
 from .model_uncertainty import ClassifierUncertaintyDrift, RegressorUncertaintyDrift
 from .tabular import TabularDrift
 
@@ -9,7 +12,10 @@ __all__ = [
     "ChiSquareDrift",
     "ClassifierDrift",
     "KSDrift",
+    "LSDDDrift",
+    "LSDDDriftOnline",
     "MMDDrift",
+    "MMDDriftOnline",
     "TabularDrift",
     "ClassifierUncertaintyDrift",
     "RegressorUncertaintyDrift"
