@@ -392,6 +392,152 @@ class BaseMMDDrift(BaseDetector):
         return cd
 
 
+class BaseLSDDDrift(BaseDetector):
+    def __init__(
+            self,
+            x_ref: np.ndarray,
+            p_val: float = .05,
+            preprocess_x_ref: bool = True,
+            update_x_ref: Optional[Dict[str, int]] = None,
+            preprocess_fn: Optional[Callable] = None,
+            sigma: Optional[np.ndarray] = None,
+            n_permutations: int = 100,
+            n_kernel_centers: Optional[int] = None,
+            lambda_rd_max: float = 0.2,
+            input_shape: Optional[tuple] = None,
+            data_type: Optional[str] = None
+    ) -> None:
+        """
+        Least-squares Density Difference (LSDD) base data drift detector using a permutation test.
+
+        Parameters
+        ----------
+        x_ref
+            Data used as reference distribution.
+        p_val
+            p-value used for the significance of the permutation test.
+        preprocess_x_ref
+            Whether to already preprocess and store the reference data.
+        update_x_ref
+            Reference data can optionally be updated to the last n instances seen by the detector
+            or via reservoir sampling with size n. For the former, the parameter equals {'last': n} while
+            for reservoir sampling {'reservoir_sampling': n} is passed.
+        preprocess_fn
+            Function to preprocess the data before computing the data drift metrics.
+        sigma
+            Optionally set the bandwidth of the Gaussian kernel used in estimating the LSDD. Can also pass multiple
+            bandwidth values as an array. The kernel evaluation is then averaged over those bandwidths. If `sigma`
+            is not specified, the 'median heuristic' is adopted whereby `sigma` is set as the median pairwise distance
+            between reference samples.
+        n_permutations
+            Number of permutations used in the permutation test.
+        n_kernel_centers
+            The number of reference samples to use as centers in the Gaussian kernel model used to estimate LSDD.
+            Defaults to 1/20th of the reference data.
+        lambda_rd_max
+            The maximum relative difference between two estimates of LSDD that the regularization parameter
+            lambda is allowed to cause. Defaults to 0.2 as in the paper.
+        input_shape
+            Shape of input data.
+        data_type
+            Optionally specify the data type (tabular, image or time-series). Added to metadata.
+        """
+        super().__init__()
+
+        if p_val is None:
+            logger.warning('No p-value set for the drift threshold. Need to set it to detect data drift.')
+
+        # optionally already preprocess reference data
+        self.p_val = p_val
+        if preprocess_x_ref and isinstance(preprocess_fn, Callable):  # type: ignore
+            self.x_ref = preprocess_fn(x_ref)
+        else:
+            self.x_ref = x_ref
+        self.sigma = sigma
+        self.preprocess_x_ref = preprocess_x_ref
+        self.update_x_ref = update_x_ref
+        self.preprocess_fn = preprocess_fn
+        self.n = x_ref.shape[0]  # type: ignore
+        self.n_permutations = n_permutations  # nb of iterations through permutation test
+        self.n_kernel_centers = n_kernel_centers or max(self.n // 20, 1)
+        self.lambda_rd_max = lambda_rd_max
+
+        # store input shape for save and load functionality
+        self.input_shape = input_shape if isinstance(input_shape, tuple) else x_ref.shape[1:]
+
+        # set metadata
+        self.meta.update({'detector_type': 'offline', 'data_type': data_type})
+
+    def preprocess(self, x: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
+        """
+        Data preprocessing before computing the drift scores.
+        Parameters
+        ----------
+        x
+            Batch of instances.
+        Returns
+        -------
+        Preprocessed reference data and new instances.
+        """
+        if isinstance(self.preprocess_fn, Callable):  # type: ignore
+            x = self.preprocess_fn(x)
+            x_ref = self.x_ref if self.preprocess_x_ref else self.preprocess_fn(self.x_ref)
+            return x_ref, x
+        else:
+            return self.x_ref, x
+
+    @abstractmethod
+    def score(self, x: np.ndarray) -> Tuple[float, float, np.ndarray]:
+        pass
+
+    def predict(self, x: np.ndarray, return_p_val: bool = True, return_distance: bool = True) \
+            -> Dict[Dict[str, str], Dict[str, Union[int, float]]]:
+        """
+        Predict whether a batch of data has drifted from the reference data.
+
+        Parameters
+        ----------
+        x
+            Batch of instances.
+        return_p_val
+            Whether to return the p-value of the permutation test.
+        return_distance
+            Whether to return the LSDD metric between the new batch and reference data.
+
+        Returns
+        -------
+        Dictionary containing 'meta' and 'data' dictionaries.
+        'meta' has the model's metadata.
+        'data' contains the drift prediction and optionally the p-value, threshold and LSDD metric.
+        """
+        # compute drift scores
+        p_val, dist, dist_permutations = self.score(x)
+        drift_pred = int(p_val < self.p_val)
+
+        # compute distance threshold
+        idx_threshold = int(self.p_val * len(dist_permutations))
+        distance_threshold = np.sort(dist_permutations)[::-1][idx_threshold]
+
+        # update reference dataset
+        if isinstance(self.update_x_ref, dict) and self.preprocess_fn is not None and self.preprocess_x_ref:
+            x = self.preprocess_fn(x)
+        self.x_ref = update_reference(self.x_ref, x, self.n, self.update_x_ref)
+        # used for reservoir sampling
+        self.n += x.shape[0]  # type: ignore
+
+        # populate drift dict
+        cd = concept_drift_dict()
+        cd['meta'] = self.meta
+        cd['data']['is_drift'] = drift_pred
+        if return_p_val:
+            cd['data']['p_val'] = p_val
+            cd['data']['threshold'] = self.p_val
+        if return_distance:
+            cd['data']['distance'] = dist
+            cd['data']['distance_threshold'] = distance_threshold
+        return cd
+
+
 class BaseUnivariateDrift(BaseDetector):
     def __init__(
             self,
