@@ -1,12 +1,16 @@
-from .distance import mmd2, mmd2_from_kernel_matrix, squared_pairwise_distance
+from .distance import mmd2, mmd2_from_kernel_matrix, squared_pairwise_distance, permed_lsdds
 from .kernels import GaussianRBF
 from .prediction import predict_batch, predict_batch_transformer
+from .misc import zero_diag, quantile
 
 __all__ = [
     "mmd2",
     "mmd2_from_kernel_matrix",
     "squared_pairwise_distance",
     "GaussianRBF",
+    "permed_lsdds",
     "predict_batch",
-    "predict_batch_transformer"
+    "predict_batch_transformer",
+    "quantile",
+    "zero_diag"
 ]
